==> solidity_0.8.19.tar.gz: solidity_0.8.19/.github/ISSUE_TEMPLATE/feature_request.md <==
---
name: Feature Request
---

<!--## Prerequisites

- First, many thanks for taking part in the community. We really appreciate that.
- We realize there is a lot of data requested here. We ask only that you do your best to provide as much information as possible so we can better help you.
- Support questions are better asked in one of the following locations:
    - [Solidity chat](https://gitter.im/ethereum/solidity)
    - [Stack Overflow](https://ethereum.stackexchange.com/)
- Ensure the issue isn't already reported (check `feature` and `language design` labels).
- If you feel uncertain about your feature request, perhaps it's better to open a language design or feedback forum thread via the issue selector, or by going to the forum directly.
    - [Solidity forum](https://forum.soliditylang.org/)

*Delete the above section and the instructions in the sections below before submitting*
-->

## Abstract

<!--Please describe by example what problem you see in the current Solidity language and reason about it.-->

## Motivation

<!--In this section you describe how you propose to address the problem you described earlier, including by giving one or more exemplary source code snippets for demonstration.-->

## Specification

<!--The technical specification should describe the syntax and semantics of any new feature. The specification should be detailed enough to allow any developer to implement the functionality.-->

## Backwards Compatibility

<!--
All language changes that introduce backwards incompatibilities must include a section describing these incompatibilities and their severity.

Please describe how you propose to deal with these incompatibilities.
-->

==> solidity_0.8.28.tar.gz: solidity_0.8.28/.github/ISSUE_TEMPLATE/feature_request.md <==
---
name: Feature Request
about: Ideas, comments or messages asking for a particular functionality to be added
  to Solidity.
title: ''
labels: feature
assignees: ''

---

<!--## Prerequisites

- First, many thanks for taking part in the community. We really appreciate that.
- We realize there is a lot of data requested here. We ask only that you do your best to provide as much information as possible so we can better help you.
- Support questions are better asked in one of the following locations:
    - [Solidity chat](https://gitter.im/ethereum/solidity)
    - [Stack Overflow](https://ethereum.stackexchange.com/)
- Ensure the issue isn't already reported (check `feature` and `language design` labels).
- If you feel uncertain about your feature request, perhaps it's better to open a language design or feedback forum thread via the issue selector, or by going to the forum directly.
    - [Solidity forum](https://forum.soliditylang.org/)

*Delete the above section and the instructions in the sections below before submitting*
-->

## Abstract

<!--Please describe by example what problem you see in the current Solidity language and reason about it.-->

## Motivation

<!--In this section you describe how you propose to address the problem you described earlier, including by giving one or more exemplary source code snippets for demonstration.-->

## Specification

<!--The technical specification should describe the syntax and semantics of any new feature. The specification should be detailed enough to allow any developer to implement the functionality.-->

## Backwards Compatibility

<!--
All language changes that introduce backwards incompatibilities must include a section describing these incompatibilities and their severity.

Please describe how you propose to deal with these incompatibilities.
-->
